#
# Copyright 2007-2020 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#
"""
This module provides DSA software versioning information for
python based components
"""
from __future__ import absolute_import
from __future__ import division

from vdsm import osinfo
from vdsm.common import cache


version_name = "Snow Man"
software_version = "4.50.0.10"
software_revision = "1"
raw_version_revision = "4.50.0.10.1"


def _get_libvirt_version():
    packages = osinfo.package_versions()
    libvirt_version = tuple(
        int(v)
        for v in packages['libvirt']['version'].split('.')
    )
    return libvirt_version[:2]


@cache.memoized
def version_info():
    cluster_levels = ['4.2', '4.3', '4.4', '4.5', '4.6']
    libvirt_version = _get_libvirt_version()

    if libvirt_version >= (8, 0):
        cluster_levels.append('4.7')

    return {
        'version_name': version_name,
        'software_version': software_version,
        'software_revision': software_revision,
        'supportedENGINEs': ['4.2', '4.3', '4.4', '4.5'],
        'clusterLevels': cluster_levels,
    }
